@@ -69,7 +69,7 @@ describe 'placement' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           {
             :python_package_name => 'python3-placement',
